"""
Copyright 2021-2024 MICRORISC s.r.o.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

	http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""

from dataclasses import dataclass
from typing import Union


@dataclass
class ControllerPins:
	"""
	Controller pins configuration class.

	Attributes
	----------
	button_pin: int
		api button pin
	ledg_pin: int
		green led pin
	ledr_pin: int
		red led pin
	sda_pin: int|None
		i2c sda pin
	sck_pin: int|None
		i2c sck pin
	"""

	def __init__(self, button_pin: int, ledg_pin: int, ledr_pin: int, sda_pin: Union[int, None] = None, sck_pin: Union[int, None] = None):
		"""
		Construct attributes for controller pins object.

		Parameters
		----------
		button_pin: int
			button pin
		ledg_pin: int
			green led pin
		ledr_pin: int
			red led pin
		sda_pin: int|None
			i2c sda pin
		sck_pin: int|None
			i2c sck pin
		"""
		self.button_pin: int = button_pin
		self.ledg_pin: int = ledg_pin
		self.ledr_pin: int = ledr_pin
		self.sda_pin: Union[int, None] = sda_pin
		self.sck_pin: Union[int, None] = sck_pin
